/* ========================================================================
 * DOM-based Routing
 * Based on http://goo.gl/EUTi53 by Paul Irish
 *
 * Only fires on body classes that match. If a body class contains a dash,
 * replace the dash with an underscore when adding it to the object below.
 *
 * .noConflict()
 * The routing is enclosed within an anonymous function so that you can
 * always reference jQuery with $, even when in .noConflict() mode.
 *
 * ======================================================================== */
jQuery(document).ready(function ($) {

    // Live search

    function MoviesSearch(args) {

      var $form = $(args.form),
        $searchInput = $(args.searchInput),
        $searchResultsHolder = $(args.searchResultsHolder),
        $searchResults = $searchResultsHolder.find('.bng-live-search-results__items'),
        $filtersToggle = $(args.filtersToggle),
        $filtersHolder = $(args.filtersHolder),
        $activeFilters = $filtersHolder.find('.bng-movies-filters__actives'),
        $selectFilters = $filtersHolder.find('select');

      var self = this;
      this.request = false;
      this.queryRequest = false;
      this.loadMore = true;
      this.page = 1;

      this.query = function (page) {
        //if ($('.bng-header-search__input').val().length < 3) {
          //return false;
        //}
        $('.bng-header-search__input').val()

        var moviesPerLoad = 20,
          startFrom = page === 1 ? 0 : (page - 1) * moviesPerLoad;

        this.request = true;

        if (page === 1) {
          $searchResults.html('');
        }

        $searchResults.append('<li class="bng-tmp">' + bingedLoader() + '</li>');
        $searchResults.animate({scrollTop: $searchResults.prop('scrollHeight')}, 100);

        var dataForRequest = $.extend({
            length: moviesPerLoad,
            start: startFrom
          },
          $form.serializeObject(),
          $('.search-hidden-data form').serializeObject()
        );

        dataForRequest['filters']['date-from'] = parseInt($('.release-slider-left').text());
        dataForRequest['filters']['date-to'] = parseInt($('.release-slider-right').text());
        if (!dataForRequest['filters'].hasOwnProperty('search') || dataForRequest['filters']['search'] == '') {
          dataForRequest['filters']['search'] = $('.bng-header-search__input').val();
        }

        return this.queryRequest = $.ajax({
          type: 'POST',
          url: '/wp-admin/admin-ajax.php',
          data: dataForRequest,
          success: function (resp) {
            self.page = page;
            var content = '';
            var platforms = '';
            var title = '';
            for (var i in resp.data) {
              platforms = '';
              title = resp.data[i]['title'];
              for (var y in resp.data[i]['platform']) {
                var activeClass = '';
                if (y == 0) {
                  activeClass = 'active';
                }
                platforms += '<img data-index="' + y + '" class="' + activeClass + '" src="' + resp.data[i]['platform'][y] + '" />';
              }

              var morePlatformsButton = '';
              if (resp.data[i]['platform'].length > 1) {
                morePlatformsButton = '<div class="search-item-platform-more"><img src="/wp-content/themes/binged/assets_new/img/more-platforms.svg"></div>';
              }

              var notifiacationButtonClass = 'active';
              if (resp.data[i]['is_in_watchlist']) {
                notifiacationButtonClass = '';
              }

              var addNotifyButton = '<div class="search-item-notification ' + notifiacationButtonClass + '" data-post_id="' + resp.data[i]['id'] + '"><svg width="40" height="40" viewBox="0 0 40 40" fill="none" xmlns="http://www.w3.org/2000/svg"> <path d="M20 40C19.4696 40 18.9609 39.7942 18.5858 39.4279C18.2107 39.0617 18 38.5649 18 38.0469V1.95312C18 1.43512 18.2107 0.938339 18.5858 0.572057C18.9609 0.205775 19.4696 0 20 0C20.5304 0 21.0391 0.205775 21.4142 0.572057C21.7893 0.938339 22 1.43512 22 1.95312V38.0469C22 38.5649 21.7893 39.0617 21.4142 39.4279C21.0391 39.7942 20.5304 40 20 40Z" fill="#CBFF37"></path> <path d="M38.0469 22H1.95312C1.43512 22 0.938339 21.7893 0.572057 21.4142C0.205775 21.0391 0 20.5304 0 20C0 19.4696 0.205775 18.9609 0.572057 18.5858C0.938339 18.2107 1.43512 18 1.95312 18H38.0469C38.5649 18 39.0617 18.2107 39.4279 18.5858C39.7942 18.9609 40 19.4696 40 20C40 20.5304 39.7942 21.0391 39.4279 21.4142C39.0617 21.7893 38.5649 22 38.0469 22Z" fill="#CBFF37"></path> </svg></div>';
              content += '<li>' +
                            '<div class="search-item">' +
                              '<div class="row">' +
                                '<div class="col">' +
                                  '<a href="' + resp.data[i]['link'] + '"><div class="search-item-img" style="background-image:url(' + resp.data[i]['image'] + ')"></div></a>' +
                                '</div>' +
                                '<div class="col">' +
                                '<div class="search-item-title"><div class="inner"><a href="' + resp.data[i]['link'] + '">' + resp.data[i]['title_mini'] + '</a></div>' + addNotifyButton + '</div>' +
                                '</div>' +
                                '<div class="col">' +
                                  '<div class="search-item-date">' + resp.data[i]['streaming-date'] + '</div>' +
                                '</div>' +
                                '<div class="col">' +
                                  morePlatformsButton +
                                  '<div class="search-item-platform">' + platforms + '</div>' +
                                '</div>' +
                              '</div>' +
                            '</div>' +
                        '</li>';
            }

            //var template = document.getElementById('bng-movie-search-result').innerHTML,
             // content = Mustache.render(template, {movies: resp.data});

            if (page > 1) {
              $searchResults.append(content);
            } else {

              $searchResults.html(content).scrollTop(0);
            }

            $('.search-item-platform-more').unbind('click');
            $('.search-item-platform-more').click(function () {
              var imageParent = $(this).parent().find('.search-item-platform');
              var activeIndex = parseInt(imageParent.find('img.active').attr('data-index'));
              var nextIndex = (activeIndex + 1);
              if (nextIndex > (imageParent.find('img').length -1)) {
                nextIndex = 0;
              }

              imageParent.find('img').removeClass('active');
              imageParent.find('img').eq(nextIndex).addClass('active');
            });

            $('.search-item-notification').unbind('click');
            $('.search-item-notification').click(function () {
              var $self = $(this);
              if (bingedData.isLoggedIn) {
                manageNotification(this).always(function () {
                }).done(function (resp) {
                  if (resp.success) {
                    $('body').trigger('binged-manage-notifications', [resp.data]);
                    if (resp.data.action == 'removed') {
                      $self.addClass('active');
                    } else {
                      $self.removeClass('active');
                    }
                  }
                });
              } else {
                bingedOpenLoginPopup();
              }
            });


            if (page === 1 && resp.data.length === 0) {
              $searchResults.append('<li class="no-results-li">No results found</li>');
            }

            if (resp.data.length < moviesPerLoad) {
              self.loadMore = false;
            }

          },
          complete: function () {
            $searchResults.find('.bng-tmp').remove();
            self.request = false;
          }
        });

      }

      $searchInput
        .bind('input', function () {
          console.log('before abort', self.queryRequest);
          if (self.queryRequest) {
            console.log('abort');
            self.queryRequest.abort();
          }
        })
        .bind('input', (bingedDebounce(function (e) {

          if ($(this).val().trim() !== "" || 1==1) {
            $searchResultsHolder.addClass('bng-active');
            $('.new-design-header-search').addClass('active');
            self.query(1);
          } else {
            $searchResultsHolder.removeClass('bng-active');
            $('.new-design-header-search').removeClass('active');
          }

        }, 1000)));

      $searchResults.scroll(function () {
        var isLoadMore = $(this).scrollTop() === $(this).prop('scrollHeight') - $(this).outerHeight();
        if (isLoadMore && self.loadMore && !self.request) {
          self.query(self.page + 1);
        }
      });

      $searchInput.on('focusin', function () {
        if ($(this).val() !== "" || 1==1) {
          $searchResultsHolder.addClass('bng-active');
          $('.new-design-header-search').addClass('active');
        }
      });

      $(window).click(function () {
        if ($searchResultsHolder.hasClass('bng-active')) {
          $searchResultsHolder.removeClass('bng-active');
          $('.new-design-header-search').removeClass('active');
        }
      });

      $searchResultsHolder.click(function (event) {
        event.stopPropagation();
      });

      $searchInput.click(function (event) {
        event.stopPropagation();

        if ($filtersHolder.hasClass('bng-active')) {
          $filtersHolder
            .removeClass('bng-active')
            .trigger('bng-search:filters-closed');
        }

      });

      $filtersToggle.click(function () {
        if ($('.bng-header-search__input').val().length >= 0) {
          $searchResultsHolder.removeClass('bng-active');
          $('.new-design-header-search').removeClass('active');

          var action = $filtersHolder.hasClass('bng-active') ? 'closed' : 'opened';

          $filtersHolder
            .trigger('bng-search:filters-' + action)
            .toggleClass('bng-active');
        }
      });

      $filtersHolder.on('bng-search:filters-opened', function () {
        $filtersToggle.addClass('bng-active bng-close');
      });

      $filtersHolder.on('bng-search:filters-closed', function () {
        $filtersToggle.removeClass('bng-active bng-close');

        //if ($searchInput.val().trim() !== "") {
          $('.bng-header-search__input').trigger('input');
        //}

      });

      $selectFilters.change(function () {
        /*
        var isActive = false;
        $activeFilters.hide();
        $activeFilters.find('.bng-movies-filters__actives-group').remove();

        $selectFilters.each(function () {

          var $filter = $(this),
            $group = $('<div>')
              .addClass('bng-movies-filters__actives-group')
              .data('filter', $filter.attr('id'));

          var values = $(this).val();

          if (!values) {
            return;
          }

          values = Array.isArray(values) ? values : [values];

          console.log(values);

          $.each(values, function (i, value) {

            var $tag = $('<div>')
              .addClass('bng-movies-filters__actives-tag')
              .addClass('bng-movies-filters__actives-tag--remove')
              .text($filter.find('option[value="' + value + '"]').text())
              .data('value', value);

            $group.append($tag);

            isActive = true;

          });

          $activeFilters.append($group);

        });

        if (isActive) {
          $activeFilters.show();
        }
         */
      });



      $activeFilters.on('click', '.bng-movies-filters__actives-tag--remove', function () {

        var filter = $(this).parents('.bng-movies-filters__actives-group').data('filter'),
          value = $(this).data('value'),
          $filter = $selectFilters.filter('[id="' + filter + '"]');

        if ($filter.length > 0) {
          $filter[0].sumo.unSelectItem(value);
        }

      });

    }

    // Desktop Search
    new MoviesSearch({
      form: '.bng-header-search',
      searchInput: '.bng-header-search__input',
      searchResultsHolder: '.bng-header-search__results',
      filtersToggle: '.filter-button',
      filtersHolder: '.search-filters',
    });

    // Mobile Search

    $('.bng-header-mobile__search-toggle').click(function (e) {
      e.stopPropagation();

      $('.bng-header-mobile__search').addClass('bng-active');
      $('.bng-header-mobile-search__input').focus();

    });

    $('.bng-header-mobile-search__input').on('ontouchend', function () {
      $(this).focus();
    });

    $('.bng-header-mobile-search__close').click(function () {
      $('.bng-header-mobile .bng-active').removeClass('bng-active');
      $('.bng-header-mobile-search__filters-toggle').removeClass('bng-close');
    });

    new MoviesSearch({
      form: '.bng-header-mobile-search',
      searchInput: '.bng-header-mobile-search__input',
      searchResultsHolder: '.bng-header-mobile-search__results',
      filtersToggle: '.bng-header-mobile-search__filters-toggle',
      filtersHolder: '.bng-header-mobile-search__filters',
    });

    /*$(".bng-header-holder").stickybits({
       useStickyClasses: !0,
       noStyles: !0,
       useFixed: !0,
       stickyClass: "bng-header-holder--sticky",
       stuckClass: "bng-header-holder--sticky"
     });
     */

    // Drawer

    $('.bng-drawer-open').click(function (e) {
      e.preventDefault();
      $($(this).attr('href')).addClass('active');
      $(document.body).addClass('no-scroll');
    });

    $('.bng-drawer__close').click(function () {
      $(this).closest('.bng-drawer').removeClass('active');
      $(document.body).removeClass('no-scroll');
    });


    // Tabs

    $('.bng-tabs__tab').click(function () {

      var id = $(this).data('id'),
        $tabs = $(this).parents('.bng-tabs'),
        $currentContent = $tabs.find('.bng-tabs__content[data-id="' + id + '"]');

      $tabs.find('.bng-tabs__tab').removeClass('bng-tabs__tab--active');
      $(this).addClass('bng-tabs__tab--active');

      $tabs.find('.bng-tabs__content').removeClass('bng-tabs__content--active');
      $currentContent.addClass('bng-tabs__content--active');

    }).first().click();

    $('.bng-tabs__tab').each(function () {

      var id = $(this).data('id'),
        $tabs = $(this).parents('.bng-tabs'),
        $content = $tabs.find('.bng-tabs__content[data-id="' + id + '"]');

      if ($content.text().trim() === "") {
        $(this).hide();
      }

    });


    // Add to Watched

    $(document.body).on('click', '.bng-watched-btn', function () {

      var $self = $(this);

      if (bingedData.isLoggedIn) {

        $self.addClass('loading');

        slManageWatched(this).always(function () {
          $self.removeClass('loading');
        }).done(function (resp) {
          if (resp.success) {
            $('body').trigger('binged-manage-watched', [resp.data]);
          }
        });

      } else {
        bingedOpenLoginPopup();
      }

    });


    // Notification Btn
    $(document.body).on('click', '.bng-notification-btn, .search-item-notification', function () {

      var $self = $(this);

      if (bingedData.isLoggedIn) {

        $self.addClass('loading');

        manageNotification(this).always(function () {
          $self.removeClass('loading');
        }).done(function (resp) {
          if (resp.success) {
            $('body').trigger('binged-manage-notifications', [resp.data]);
          }
        });

      } else {
        bingedOpenLoginPopup();
      }

    });

    // What to watch Notification

    /*
        $(document.body).on('click', '.bng-what-to-watch-badge__close', function (e) {
          e.preventDefault();
          $(this).parents('.bng-what-to-watch-badge').fadeOut();
          sessionStorage.setItem('binged-skip-what-to-watch', 1)
        });

        $(window).on('scroll', onLoadWhatToWatch);

        function onLoadWhatToWatch() {
          if ($(document).scrollTop() >= 50) {
            loadWhatToWatch();
            $(window).unbind('scroll', onLoadWhatToWatch);
          }
        }

        function loadWhatToWatch() {

          var skip = sessionStorage.getItem('binged-skip-what-to-watch');

          if (skip) {
            return false;
          }

          $.ajax({
            type: 'POST',
            url: bingedData.ajaxUrl,
            data: {
              action: 'binged_load_what_to_watch'
            },
            success: function (data) {
              $('body').append(data);
            },
          });

        }
    */

    // Account validated success notification

    if (location.hash === '#account-validated') {
      toastr.info('Thank you, your account is validated.');
      location.hash = '';
    }

    $('.bng-header-menu a[href="#"]').click(function (e) {
      e.preventDefault();
    });

    // Streaming Notifications

    updateNotificationsCount();

    $('body').on('click', '.bng-notifications__item button', function () {

      var $self = $(this);

      $self.addClass('loading');

      $.ajax({
        type: 'POST',
        url: bingedData.ajaxUrl,
        data: {
          action: 'bng_remove_streaming_notification',
          id: $self.data('id')
        },
        success: function (resp) {
          if (resp.success) {
            location = $self.data('link');
          }
        },
        error: function (xhr, ajaxOptions, thrownError) {
          console.log('error...', xhr);
          $self.removeClass('loading');
        }
      });

    });

    function manageNotification(el) {

      var $self = $(el),
        postId = $self.data('post_id');

      return $.ajax({
        type: 'POST',
        url: bingedData.ajaxUrl,
        data: {
          action: 'manage_notification',
          post_id: postId
        },
        success: function (resp) {

          if (resp.success) {

            switch (resp.data.action) {

              case 'added':
                $self.addClass('active');
                toastr.info('You will be notified.');
                break;
              case 'removed':
                $self.removeClass('active');
                toastr.info('Notification removed.');
                break;
              case 'settings':
                vex.dialog.confirm({
                  message: 'You don\'t have any notification method selected. Do you want to select one?',
                  callback: function (value) {
                    if (value) {
                      window.location.href = '/account/settings/';
                    }
                  }
                });
                break;
              default:
                toastr.info('Error setting up notification. Please check your account settings to be sure you enabled receiving notifications.');

            }

            if (resp.data.fragments) {
              $.each(resp.data.fragments, function (className, html) {
                if ($(className).length > 0) {
                  $(className).replaceWith(html);
                }
              });
            }

            updateNotificationsCount();

          } else {
            alert(resp.data);
          }

        }
      });

    }

    window.bingedManageNotification = manageNotification;

    function updateNotificationsCount() {
      $('.bng-notifications-count').attr('data-count', $('.bng-notifications').data('count'));
    }

    // -----------------------------------------------------

    $('.activeStars.noVoted').hover(function () {
    }, function () {
      jQuery('.activeStars.noVoted a').removeClass('active');
    });

    $('.registerOverlayOuter .formTabs .login').click(function () {
      event.preventDefault();
      $('.registerInner .loginFormOuter').fadeIn();
      $('.registerInner .registerFormOuter').hide();
      $('.registerOverlayOuter .formTabs a').removeClass('active');
      $(this).addClass('active');
    });
    $('.registerOverlayOuter .formTabs .register').click(function () {
      event.preventDefault();
      $('.registerInner .loginFormOuter').hide();
      $('.registerInner .registerFormOuter').fadeIn();
      $('.registerOverlayOuter .formTabs a').removeClass('active');
      $(this).addClass('active');
    });

    $('a[href="#bng-login"], .seen_it.login, .want_to_see.login, .event_add_btn.login, .sideBarBottomBtn.login, .createWatchListBtn.login, .watchEventBody.login, .likeEventBody.login, .watchListEventBody.login, .get_notified.login, .activeStars.login, .reviewBtn.login, .followBtn.login, .avatar.login, .signIn.login, .header-login.login, .getNotified.login').click(function () {
      event.preventDefault();
      //$('.new-design-header .custom-menu').trigger('click');
      bingedOpenLoginPopup();
    });

    $('a[href="#bng-register"], .createAcc.login').click(function () {
      event.preventDefault();
      //$('.new-design-header .custom-menu').trigger('click');
      bingedOpenRegisterPopup();
    });

    $('.registerOverlay .close.js-close-signin').click(function () {
      $('body').removeClass('no-scroll');
      $('.registerOverlayOuter').fadeOut();
    });

    $('.bng-review-popup-btn').click(function () {
      event.preventDefault();
      $('.popupCommentOuter').fadeIn();
    });

    $('.popupCommentOuter .close.js-close-signin').click(function () {
      $('.popupCommentOuter').fadeOut();
    });
    // Login
    $('#loginFormPopup').submit(function (e) {
      e.preventDefault();
      $.ajax({
        url: __rest_login_url,
        data: {
          username: jQuery('.registerOverlayOuter .loginFormOuter #username').val(),
          password: jQuery('.registerOverlayOuter .loginFormOuter #password').val(),
          remember: jQuery('.registerOverlayOuter .loginFormOuter #remember').val(),
          _wp_http_referer: jQuery('.registerOverlayOuter .loginFormOuter input[name="_wp_http_referer"]').val()
        },
        method: 'POST',
        async: false,
        dataType: 'json',
        success: function( response ) {
          //console.log('ok');
          //console.log(response);
          if (response) {
            if (response.token) {
              window.location.reload();
            } else {
              $('#loginFormPopup .row.error').remove();
              $('#loginFormPopup').prepend("<div class='row error'>" + response.error + "</div>");
            }
          }
        },
        error: function( response ){
          //console.log('error');
          //console.log(response);
          $('#loginFormPopup .row.error').remove();
          $('#loginFormPopup').prepend("<div class='row error'>" + response.responseJSON.message + "</div>");
        }
      });
      /*
       $.post(
         __ajax_url,
         {
           action: 'login_form_submit',
           username: jQuery('.registerOverlayOuter .loginFormOuter #username').val(),
           password: jQuery('.registerOverlayOuter .loginFormOuter #password').val()
         },
         function (response) {
           if (response) {
             if (response.success) {
               window.location.reload();
             } else {
               //alert(response.error);
               $('#loginFormPopup .row.error').remove();
               $('#loginFormPopup').prepend("<div class='row error'>" + response.error + "</div>");
             }
           }
         },
         'json'
       );*/
    });
    // REgistration
    $('#registerFormPopup').submit(function (e) {
      e.preventDefault();
      $.ajax({
        url: __rest_base + '/registration/',
        data: {
          username: jQuery('#registerFormPopup input[name="username"]').val(),
          email: jQuery('#registerFormPopup input[name="email"]').val(),
          //phone: jQuery('#registerFormPopup input[name="phone"]').val(),
          //whatsapp: jQuery('#registerFormPopup input[name="whatsapp"]').val(),
          //notification_method: jQuery('#registerFormPopup select[name="notification_method"]').val(),
          password: jQuery('#registerFormPopup input[name="password"]').val(),
          confirm_password: jQuery('#registerFormPopup input[name="confirm_password"]').val(),
          recaptcha: jQuery('#registerFormPopup textarea[name="g-recaptcha-response"]').val(),
          _wp_http_referer: jQuery('#registerFormPopup input[name="_wp_http_referer"]').val()
        },
        method: 'POST',
        async: false,
        dataType: 'json',
        success: function( response ) {
          //console.log('ok');
          //console.log(response);
          if (true == response.success) {
            //console.log('success');
            $('#registerFormPopup .row').remove();
            $('#registerFormPopup').prepend("<div class='row conf'>" + response.msg + "</div>");
            jQuery('#registerFormPopup button').hide();
            setTimeout(function () {
              document.location.reload();
            }, 3000)
          } else {
            //console.log('failure');
            $('#registerFormPopup .row.error').remove();
            $('#registerFormPopup').prepend("<div class='row error'>" + response.error + "</div>");
            grecaptcha.reset();
          }
        },
        error: function( response ){
          //console.log('error');
          //console.log(response);
          $('#registerFormPopup .row.error').remove();
          $('#registerFormPopup').prepend("<div class='row error'>" + response.responseJSON.message + "</div>");
          grecaptcha.reset();
        }
      });
      /*
       $.post(
         __ajax_url,
         {
           action: 'register_form_submit',
           username: jQuery('#registerFormPopup input[name="username"]').val(),
           email: jQuery('#registerFormPopup input[name="email"]').val(),
           phone: jQuery('#registerFormPopup input[name="phone"]').val(),
           whatsapp: jQuery('#registerFormPopup input[name="whatsapp"]').val(),
           notification_method: jQuery('#registerFormPopup select[name="notification_method"]').val(),
           password: jQuery('#registerFormPopup input[name="password"]').val(),
           confirm_password: jQuery('#registerFormPopup input[name="confirm_password"]').val(),
           recaptcha: jQuery('#registerFormPopup textarea[name="g-recaptcha-response"]').val()
         },
         function (response) {
           if (response) {
             if (response.success) {
               window.location.reload();
               // $('#registerFormPopup').html('<div class="success">' + response.msg + '</div>');
             } else {
               grecaptcha.reset();
               $('#registerFormPopup .row.error').remove();
               $('#registerFormPopup').prepend("<div class='row error'>" + response.error + "</div>");
             }
           }
         },
         'json'
       );*/
    });

    $(document).mousedown(function (e) {
      var container = $(".headerMenu .loginPopUp");
      // if the target of the click isn't the container nor a descendant of the container
      if (!container.is(e.target) && container.has(e.target).length === 0) {
        container.fadeOut();
      }

      var container2 = $(".registerInner");
      // if the target of the click isn't the container nor a descendant of the container
      if (!container2.is(e.target) && container2.has(e.target).length === 0 && $(".registerOverlayOuter").css('display') == 'block') {
        //alert('123');
        $(".registerOverlayOuter").fadeOut();
        $('body').removeClass('no-scroll');
      }

      var container3 = $(".desktop-search");
      // if the target of the click isn't the container nor a descendant of the container
      if (!container3.is(e.target) && container3.has(e.target).length === 0) {
        container3.fadeOut();
      }
    });

    $('.header-open-nav').click(function () {
      $(this).toggleClass('active');
      $('.header-mobile-nav').toggleClass('show');
      $('.header-login-modal').removeClass('show');
      $('.header-search-modal').removeClass('show');
    });

    $('.header-search').click(function () {
      $(this).toggleClass('active');
      $('.header-search-modal').toggleClass('show');
      $('.header-login-modal').removeClass('show');
      $('.header-open-nav').removeClass('active');
      $('.header-mobile-nav').removeClass('show');
    });

    $('.desktop-search-button').click(function () {
      $('.desktop-search').fadeIn();
    });

    $('.main-menu > ul > li.menu-item-has-children > a').click(function (e) {
      e.preventDefault();
      $(this).parent('li.menu-item-has-children').toggleClass('parent-menu-visible');
      $(this).parent('li.menu-item-has-children').find('ul.menu-posts').removeClass('menu-visible');
      $(this).parent('li.menu-item-has-children').find('ul.sub-menu li:first-child ul.menu-posts')
        .addClass('menu-visible');
    });

    $('.subheader-1, .td-main-content-wrap').click(function () {
      if ($('.main-menu > ul > li.menu-item-has-children').hasClass('parent-menu-visible'))
        $('.main-menu > ul > li.menu-item-has-children').removeClass('parent-menu-visible')

      if ($('.header .subheader-2 .header-search').hasClass('opened'))
        $('.header .subheader-2 .header-search').removeClass('opened')
    });

    $('.main-menu .sub-menu > li').hover(function () {
      $(this).parent('.sub-menu').find('ul.menu-posts').removeClass('menu-visible');
      $(this).find('ul.menu-posts').addClass('menu-visible');
    });
    

    $('.bng-trailers-widget ul').on('afterChange', function (event, slick, currentSlide) {

      $('.bng-trailers-widget .heading .title').text($('.bng-trailers-widget li[data-slick-index=' + currentSlide + ']').find('.title').text());
      $('.bng-trailers-widget li').find('.title').show();
      $('.bng-trailers-widget li').find('.controls').hide();
      $('.bng-trailers-widget li').removeClass('slider-bordered');

      $('.bng-trailers-widget li[data-slick-index=' + currentSlide + ']').find('.title').hide();
      $('.bng-trailers-widget li[data-slick-index=' + currentSlide + ']').find('.controls').show();
      $('.bng-trailers-widget li[data-slick-index=' + currentSlide + ']').addClass('slider-bordered');

    });

    if ($('.bng-trailers-widget ul').length > 0) {
      $('.bng-trailers-widget .heading .title').text($('.bng-trailers-widget li[data-slick-index=0]').find('.title').text());
      $('.bng-trailers-widget li').find('.controls').hide();
      $('.bng-trailers-widget li[data-slick-index=0]').find('.title').hide();
      $('.bng-trailers-widget li[data-slick-index=0]').find('.controls').show();
      $('.bng-trailers-widget li[data-slick-index=0]').addClass('slider-bordered');
    }

    $('.header .subheader-2 .header-search a').click(function (e) {
      if ($('body').width() > 600) {
        e.preventDefault();
        $(this).parent().toggleClass('opened');
      }
    });

    
  $('.bng-watchlist-btn').unbind('click');
  $('.bng-watchlist-btn').click(function () {
    var $self = $(this);
    if (bingedData.isLoggedIn) {
      slManageWachList(this).always(function () {
      }).done(function (resp) {
        if (resp.success) {
          $('body').trigger('binged-manage-watchlist', [resp.data]);
          console.log(resp.data.action);
          if (resp.data.action == 'remove') {
            $self.removeClass('active');
          } else {
            $self.addClass('active');
          }
        }
      });
    } else {
      bingedOpenLoginPopup();
    }
  });

  $('.single-mevents-tubs-items-item-reminder-add').unbind('click');
  $('.single-mevents-tubs-items-item-reminder-add').click(function () {
    var $self = $(this);
    if (bingedData.isLoggedIn) {
      manageNotification(this).always(function () {
      }).done(function (resp) {
        if (resp.success) {
          $('body').trigger('binged-manage-notifications', [resp.data]);
          var value = parseInt($('.single-mevents-tubs-names-item-notification-count').text());
          if (resp.data.action == 'removed') {
            value--;
          } else {
            value++;
          }
          $('.single-mevents-tubs-names-item-notification-count').text(value);
          var buttonText = $self.text();
          var buttonText2 = $self.attr('data-text');
          $self.text(buttonText2).attr('data-text', buttonText);
        }
      });
    } else {
      bingedOpenLoginPopup();
    }
  });



  $('.bng-delete-btn-notify').unbind('click');
  $('.bng-delete-btn-notify').click(function () {
    var $self = $(this);
    manageNotification(this).always(function () {
    }).done(function (resp) {
      if (resp.success) {
        $('body').trigger('binged-manage-notifications', [resp.data]);
        $self.addClass('activated');
        setTimeout(function () {
          $self.parent().parent().slideUp(300);
          var count = parseInt($('.single-mevents-tubs-names-item[data-tub="3"] .single-mevents-tubs-names-item-seenlist-count').text()) - 1;
          $('.single-mevents-tubs-names-item[data-tub="3"] .single-mevents-tubs-names-item-seenlist-count').text(count);
        }, 300);
      }
    });
  });

  $('.single-mevents-tubs-items-item-watchlist-add').unbind('click');
  $('.single-mevents-tubs-items-item-watchlist-add').click(function () {
    var $self = $(this);
    if (bingedData.isLoggedIn) {
      slManageWachList(this).always(function () {
      }).done(function (resp) {
        if (resp.success) {
          $('body').trigger('binged-manage-watchlist', [resp.data]);
          var value = parseInt($('.single-mevents-tubs-names-item-watchlist-count').text());
          var userId = bingedData.currentUserID;
          if (resp.data.action == 'remove') {
            value--;
            $('.watchlist-row[data-user="' + userId + '"]').slideUp(300);
          } else {
            value++;
            $('.watchlist-row[data-user="' + userId + '"]').slideDown(300);
          }
          $('.single-mevents-tubs-names-item-watchlist-count').text(value);
          var buttonText = $self.text();
          var buttonText2 = $self.attr('data-text');
          $self.text(buttonText2).attr('data-text', buttonText);
        }
      });
    } else {
      bingedOpenLoginPopup();
    }

  });

  $('.bng-delete-btn-watchlist').unbind('click');
  $('.bng-delete-btn-watchlist').click(function () {
    var $self = $(this);
    slManageWachList(this).always(function () {
    }).done(function (resp) {
      if (resp.success) {
        $('body').trigger('binged-manage-watchlist', [resp.data]);
        $self.addClass('activated');
        setTimeout(function () {
          $self.parent().parent().parent().slideUp(300);
          var count = parseInt($('.single-mevents-tubs-names-item[data-tub="1"] .single-mevents-tubs-names-item-watchlist-count').text()) - 1;
          $('.single-mevents-tubs-names-item[data-tub="1"] .single-mevents-tubs-names-item-watchlist-count').text(count);
        }, 300)
      }
    });

  });


  $('.single-mevents-tubs-items-item-seenlist-add').unbind('click');
  $('.single-mevents-tubs-items-item-seenlist-add').click(function () {
    var $self = $(this);
    if (bingedData.isLoggedIn) {
      slManageWatched(this).always(function () {
      }).done(function (resp) {
        if (resp.success) {
          $('body').trigger('binged-manage-watched', [resp.data]);
          var value = parseInt($('.single-mevents-tubs-names-item-seenlist-count').text());
          var userId = bingedData.currentUserID;
          if (resp.data.action == 'remove') {
            $('.seenlist-row[data-user="' + userId + '"]').slideUp(300);
            value--;
          } else {
            $('.seenlist-row[data-user="' + userId + '"]').slideDown(300);
            value++;
          }
          $('.single-mevents-tubs-names-item-seenlist-count').text(value);
          var buttonText = $self.text();
          var buttonText2 = $self.attr('data-text');
          $self.text(buttonText2).attr('data-text', buttonText);
        }
      });

    } else {
      bingedOpenLoginPopup();
    }

  });

  $('.bng-delete-btn-watched').unbind('click');
  $('.bng-delete-btn-watched').click(function () {
    var $self = $(this);
    slManageWatched(this).always(function () {
    }).done(function (resp) {
      if (resp.success) {
        $('body').trigger('binged-manage-watched', [resp.data]);
        $self.addClass('activated');
        setTimeout(function () {
          $self.parent().parent().parent().slideUp(300);
          var count = parseInt($('.single-mevents-tubs-names-item[data-tub="2"] .single-mevents-tubs-names-item-seenlist-count').text()) - 1;
          $('.single-mevents-tubs-names-item[data-tub="2"] .single-mevents-tubs-names-item-seenlist-count').text(count);
        }, 300);
      }
    });
  });

  }
);